package ftcomputing.robo;

/**
 * Klasse fr das einfache Ansprechen des jeweiligen Interface-Einganges durch
 * die Klasse JavaFish. Geeignet fr RoboInterface und Intelligent Interface.<br>
 * Beim Intelligent-Interface gilt es, folgendes zu beachten:
 * <ul>
 * <li>keine Distanzeingnge <code>(D1 und D2)</code></li>
 * <li>keine Spannungseingnge <code>(A1 und A2)</code></li>
 * <li>nur ein Extensionmodul, weniger Digital-Eingnge</li>
 * <li><code>AX</code> entspricht <code>EX</code>, <code>AY</code> entspricht
 * <code>EY</code></li>
 * <li><code>I1</code> entspricht <code>E1</code>, usw.</li>
 * </ul>
 * 
 * @author Michael Fennel
 * @author Ulrich Mller
 * @see FishFace#getInput(int)
 * @see FishFace#getInputs()
 * @see FishFace#setCounter(int, int)
 * @see FishFace#clearCounter(int)
 * @see FishFace#waitForChange
 * @see FishFace#waitForHigh(int)
 * @see FishFace#waitForInput
 * @see FishFace#waitForLow(int)
 * @see FishFace#getAnalog(int)
 * @see FishFace#getDistance(int)
 * 
 */
public class Inp {
	/**
	 * 1&#46; analoger Wiederstandseingang <code>(AX)</code>
	 */
	public static final int AX = 1;
	/**
	 * 2&#46; analoger Wiederstandseingang <code>(AY)</code>
	 */
	public static final int AY = 2;
	/**
	 * 3&#46; analoger Wiederstandseingang <code>(AXS1)</code>, nur bei
	 * angeschlossenen Extensions-Modul 1
	 */
	public static final int AXS1 = 3;
	/**
	 * 4&#46; analoger Wiederstandseingang <code>(AXS2)</code>, nur bei
	 * angeschlossenen Extensions-Modul 2
	 */
	public static final int AXS2 = 4;
	/**
	 * 5&#46; analoger Wiederstandseingang <code>(AXS3)</code>, nur bei
	 * angeschlossenen Extensions-Modul 3
	 */
	public static final int AXS3 = 5;
	/**
	 * 1&#46; analoger Spannungseingang <code>(A1)</code>
	 */
	public static final int A1 = 1;
	/**
	 * 2&#46; analoger Spannungseingang <code>(A2)</code>
	 */
	public static final int A2 = 2;
	/**
	 * Betriebsspannung <code>(AV)</code>
	 */
	public static final int AV = 3;
	/**
	 * Spannung vom Slave Modul-Bus
	 * <p>
	 * wurde von Fischertechnik nicht richtig dokumentiert
	 */
	public static final int AZ = 4;
	/**
	 * 1&#46; digitaler Abstandseingang <code>(D1)</code>
	 */
	public static final int D1 = 1;
	/**
	 * 2&#46; digitaler Abstandseingang <code>(D2)</code>
	 */
	public static final int D2 = 2;
	/**
	 * 1&#46; digitaler Abstandseingang in Volt-Mode, wurde von Fischertechnik
	 * nicht richtig dokumentiert<br>
	 * <b>Besser nicht benutzen!</b>
	 * 
	 * @deprecated Distance-Mode sollte nicht manuell eingestellt werden!
	 */
	public static final int D1V = 5;
	/**
	 * 2&#46; digitaler Abstandseingang in Volt-Mode, wurde von Fischertechnik
	 * nicht richtig dokumentiert<br>
	 * <b>Besser nicht benutzen!</b>
	 * 
	 * @deprecated Distance-Mode sollte nicht manuell eingestellt werden!
	 */
	public static final int D2V = 6;
	/**
	 * 1&#46; Digitaleingang <code>(I1)</code>
	 */
	public static final int I1 = 1;
	/**
	 * 2&#46; Digitaleingang <code>(I2)</code>
	 */
	public static final int I2 = 2;
	/**
	 * 3&#46; Digitaleingang <code>(I3)</code>
	 */
	public static final int I3 = 3;
	/**
	 * 4&#46; Digitaleingang <code>(I4)</code>
	 */
	public static final int I4 = 4;
	/**
	 * 5&#46; Digitaleingang <code>(I5)</code>
	 */
	public static final int I5 = 5;
	/**
	 * 6&#46; Digitaleingang <code>(I6)</code>
	 */
	public static final int I6 = 6;
	/**
	 * 7&#46; Digitaleingang <code>(I7)</code>
	 */
	public static final int I7 = 7;
	/**
	 * 8&#46; Digitaleingang <code>(I8)</code>
	 */
	public static final int I8 = 8;
	/**
	 * 9&#46; Digitaleingang <code>(I9)</code>, nur bei angeschlossenen
	 * Extensions-Modul 1
	 */
	public static final int I9 = 9;
	/**
	 * 10&#46; Digitaleingang <code>(I10)</code>, nur bei angeschlossenen
	 * Extensions-Modul 1
	 */
	public static final int I10 = 10;
	/**
	 * 11&#46; Digitaleingang <code>(I11)</code>, nur bei angeschlossenen
	 * Extensions-Modul 1
	 */
	public static final int I11 = 11;
	/**
	 * 12&#46; Digitaleingang <code>(I12)</code>, nur bei angeschlossenen
	 * Extensions-Modul 1
	 */
	public static final int I12 = 12;
	/**
	 * 13&#46; Digitaleingang <code>(I13)</code>, nur bei angeschlossenen
	 * Extensions-Modul 1
	 */
	public static final int I13 = 13;
	/**
	 * 14&#46; Digitaleingang <code>(I14)</code>, nur bei angeschlossenen
	 * Extensions-Modul 1
	 */
	public static final int I14 = 14;
	/**
	 * 15&#46; Digitaleingang <code>(I15)</code>, nur bei angeschlossenen
	 * Extensions-Modul 1
	 */
	public static final int I15 = 15;
	/**
	 * 16&#46; Digitaleingang <code>(I16)</code>, nur bei angeschlossenen
	 * Extensions-Modul 1
	 */
	public static final int I16 = 16;
	/**
	 * 17&#46; Digitaleingang <code>(I17)</code>, nur bei angeschlossenen
	 * Extensions-Modul 2
	 */
	public static final int I17 = 17;
	/**
	 * 18&#46; Digitaleingang <code>(I18)</code>, nur bei angeschlossenen
	 * Extensions-Modul 2
	 */
	public static final int I18 = 18;
	/**
	 * 19&#46; Digitaleingang <code>(I19)</code>, nur bei angeschlossenen
	 * Extensions-Modul 2
	 */
	public static final int I19 = 19;
	/**
	 * 20&#46; Digitaleingang <code>(I20)</code>, nur bei angeschlossenen
	 * Extensions-Modul 2
	 */
	public static final int I20 = 20;
	/**
	 * 21&#46; Digitaleingang <code>(I21)</code>, nur bei angeschlossenen
	 * Extensions-Modul 2
	 */
	public static final int I21 = 21;
	/**
	 * 22&#46; Digitaleingang <code>(I22)</code>, nur bei angeschlossenen
	 * Extensions-Modul 2
	 */
	public static final int I22 = 22;
	/**
	 * 23&#46; Digitaleingang <code>(I23)</code>, nur bei angeschlossenen
	 * Extensions-Modul 2
	 */
	public static final int I23 = 23;
	/**
	 * 24&#46; Digitaleingang <code>(I24)</code>, nur bei angeschlossenen
	 * Extensions-Modul 2
	 */
	public static final int I24 = 24;
	/**
	 * 25&#46; Digitaleingang <code>(I25)</code>, nur bei angeschlossenen
	 * Extensions-Modul 3
	 */
	public static final int I25 = 25;
	/**
	 * 26&#46; Digitaleingang <code>(I26)</code>, nur bei angeschlossenen
	 * Extensions-Modul 3
	 */
	public static final int I26 = 26;
	/**
	 * 27&#46; Digitaleingang <code>(I27)</code>, nur bei angeschlossenen
	 * Extensions-Modul 3
	 */
	public static final int I27 = 27;
	/**
	 * 28&#46; Digitaleingang <code>(I28)</code>, nur bei angeschlossenen
	 * Extensions-Modul 3
	 */
	public static final int I28 = 28;
	/**
	 * 29&#46; Digitaleingang <code>(I29)</code>, nur bei angeschlossenen
	 * Extensions-Modul 3
	 */
	public static final int I29 = 29;
	/**
	 * 30&#46; Digitaleingang <code>(I30)</code>, nur bei angeschlossenen
	 * Extensions-Modul 3
	 */
	public static final int I30 = 30;
	/**
	 * 31&#46; Digitaleingang <code>(I31)</code>, nur bei angeschlossenen
	 * Extensions-Modul 3
	 */
	public static final int I31 = 31;
	/**
	 * 32&#46; Digitaleingang <code>(I32)</code>, nur bei angeschlossenen
	 * Extensions-Modul 3
	 */
	public static final int I32 = 32;

}
