package ftcomputing.robo;

/**
 * Basisklasse mit native Deklarationen fr javaFish40.DLL. javaFish40.DLL ist
 * eine Wrapper.DLL, die umFish40.DLL javakonform 1:1 kapselt. Zustzlich
 * enthalten sind einige Win32-API Funktionen (escape, getTickCount, sleep). Es
 * wird nicht empfoheln diese Klasse in Programme zu verwenden, sondern die
 * {@link FishFace}-Klasse.
 * 
 * @author Michael Fennel
 * @author Ulrich Mller
 */

public class JavaFish {
	/**
	 * Verbindung ber USB herstellen ggf. ber das RF-Datalink. In diesem Fall
	 * wird das erste passende Interface mit gleicher RF-Kanalnummer und
	 * beliebiger Unterkanalnummer genutzt. Distance-Mode steht auf Ultra-Sonic.
	 * 
	 * @param ifTyp
	 *            Interface-Typ
	 * @param SerialNr
	 *            Seriennummer
	 * @return iHandle
	 */
	public native int jrOpenInterfaceUSB(int ifTyp, int SerialNr);

	/**
	 * Verbindung ber USB herstellen ggf. ber das RF-Datalink. In diesem Fall
	 * wird das erste passende Interface mit gleicher RF-Kanalnummer und
	 * beliebiger Unterkanalnummer genutzt. Distance-Mode einstellbar.<br>
	 * <b>Verwendung von Distance-Mode Voltage wird nicht empfohlen!</b>
	 * @deprecated Distance-Mode sollte nicht manuell eingestellt werden!
	 * 
	 * @param ifTyp
	 *            Interface-Typ
	 * @param SerialNr
	 *            Seriennummer
	 * @param DistanceMode
	 * @return iHandle
	 */
	public native int jrOpenInterfaceUSBdis(int ifTyp, int SerialNr,
			int DistanceMode);

	/**
	 * Verbindung ber COM herstellen. Distance-Mode Ultra-Sonic.
	 * 
	 * @param ifTyp
	 *            Interface-Typ
	 * @param ComNr
	 *            COM-Port
	 * @return iHandle
	 */
	public native int jrOpenInterfaceCOM(int ifTyp, int ComNr, int AnalogZyklen);

	/**
	 * Beenden der Verbindung zum Interface
	 * 
	 * @param iHandle
	 *            iHandle
	 * @return Fehldercode
	 */
	public native int jrCloseInterface(int iHandle);

	/**
	 * Auslesen des Zustandes des angegebenen I-Einganges
	 * 
	 * @param iHandle
	 *            iHandle
	 * @param InputNr
	 *            I-Eingang
	 * @return Wert am I-Eingang
	 */
	public native int jrGetInput(int iHandle, int InputNr);

	/**
	 * Auslesen aller I-Eingnge
	 * 
	 * @param iHandle
	 *            iHandle
	 * @return Wert aller I-Eingnge
	 */
	public native int jrGetInputs(int iHandle);

	/**
	 * Auslesen eines Analogeinganges
	 * 
	 * @param iHandle
	 *            iHandle
	 * @param AnalogNr
	 *            Analogeingang
	 * @return Wert des Analogeingangs
	 */
	public native int jrGetAnalog(int iHandle, int AnalogNr);

	/**
	 * Auslesen des Zustandes des angegebenen IR-Keys des IR-Senders
	 * 
	 * @param iHandle
	 *            iHandle
	 * @param Code
	 *            Code des Senders
	 * @param KeyNr
	 *            Nummer der Taste
	 * @return Taste gedrckt oder nicht
	 */
	public native int jrGetIRKey(int iHandle, int Code, int KeyNr);

	/**
	 * Auslesen des Volt-Wertes des angegebenen A-Einganges (A1  A2) Mglich
	 * ist auch die Nutzung von D1 und D2 bei Open mit DistanceMode = Voltage
	 * Vorsicht : Sicherstellen, dass wirklich der richtige DistanceMode
	 * eingestellt wurde, man kann auch vorsichtshalber Vorwiderstnde nutzen
	 * (220  470 Ohm)
	 * 
	 * @param iHandle
	 *            iHandle
	 * @param VoltNr
	 *            Nummer des Eingangs
	 * @return Volt-Wert
	 */
	public native int jrGetVoltage(int iHandle, int VoltNr);

	/**
	 * Setzen eines Motors mit voller Geschwindigkeit
	 * 
	 * @param iHandle
	 *            iHandle
	 * @param MotNr
	 *            Nummer des Motors
	 * @param Dir
	 *            Drehrichtung
	 * @return Fehlercode
	 */
	public native int jrSetMotor(int iHandle, int MotNr, int Dir);

	/**
	 * Setzen eines Motors mit einer bestimmten Geschwindigkeit
	 * 
	 * @param iHandle
	 *            iHandle
	 * @param MotNr
	 *            Nummder des Motors
	 * @param Dir
	 *            Drehrichtung
	 * @param Speed
	 *            Geschwindigkeit
	 * @return Fehlercode
	 */
	public native int jrSetMotorEx(int iHandle, int MotNr, int Dir, int Speed);

	/**
	 * Einschaltstatus aller M-Ausgnge (M1 rechts, 2bit) abfragen
	 * 
	 * @param iHandle
	 *            iHandle
	 * @return Einschaltstatus aller M-Ausgnge
	 */
	public native int jrGetMotors(int iHandle);

	/**
	 * Alle Motoren setzen
	 * 
	 * @param iHandle
	 *            iHandle
	 * @param MotorStatus
	 *            Motorstatus
	 * @return Fehlercode
	 */
	public native int jrSetMotors(int iHandle, int MotorStatus);

	/**
	 * Alle Motoren setzen mit Angabe der Geschwindigkeit
	 * 
	 * @param iHandle
	 *            iHandle
	 * @param MotorStatus
	 *            Motorstatus
	 * @param SpeedStatus
	 *            Geschwindigkeit
	 * @param SpeedStatus16
	 *            Geschwindigkeit (nicht dokumentiert)
	 * @return Fehlercode
	 */
	public native int jrSetMotorsEx(int iHandle, int MotorStatus,
			int SpeedStatus, int SpeedStatus16);

	/**
	 * Abfragen des Mode-Status eines M-Ausganges
	 * 
	 * @param iHandle
	 *            iHandle
	 * @param MotNr
	 *            der M-Ausgang
	 * @return Mode-Status
	 */
	public native int jrGetModeStatus(int iHandle, int MotNr);

	/**
	 * Setzen des Mode-Status eines M-Ausganges
	 * 
	 * @param iHandle
	 *            iHandle
	 * @param MotNr
	 *            der M-Ausgang
	 * @param Mode
	 *            der zu setzende Modus
	 * @return Fehlercode
	 */
	public native int jrSetModeStatus(int iHandle, int MotNr, int Mode);

	/**
	 * Schalten eines O-Ausgangs
	 * 
	 * @param iHandle
	 *            iHandle
	 * @param LampNr
	 *            O-Ausgang
	 * @param OnOff
	 *            Zustand
	 * @return Fehlercode
	 */
	public native int jrSetLamp(int iHandle, int LampNr, int OnOff);

	/**
	 * Schalten eines O-Ausgangs mit Angabe der Helligkeit
	 * 
	 * @param iHandle
	 *            iHandle
	 * @param LampNr
	 *            O-Ausgang
	 * @param OnOff
	 *            Zustand
	 * @param Power
	 *            Helligkeit
	 * @return Fehlercode
	 */
	public native int jrSetLampEx(int iHandle, int LampNr, int OnOff, int Power);

	/**
	 * Starten eines M-Ausganges im RobMode (mit angeschlossenem Motor und
	 * Impulsrdchen an den zugehrenden I-Eingngen. Der Befehl luft asynchron
	 * und beendet sich bei ICount = 0 bzw. Endtaster (linksdrehend) selber
	 * 
	 * @param iHandle
	 *            iHandle
	 * @param MotNr
	 *            M-Ausgang
	 * @param Dir
	 *            Richtung
	 * @param Speed
	 *            Geschwindigkeit
	 * @param ICount
	 *            Zahl der Impulse
	 * @return Fehlercode
	 */
	public native int jrRobMotor(int iHandle, int MotNr, int Dir, int Speed,
			int ICount);

	/**
	 * Starten aller M-Ausgnge im RobMode (mit angeschlossenem Motor und
	 * Impulsrdchen an den zugehrenden I-Eingngen. Der Befehl luft asynchron
	 * und beendet sich bei ICount = 0 bzw. Endtaster (linksdrehend) selber
	 * 
	 * @param iHandle
	 *            iHandle
	 * @param MotorStatus
	 *            Motorstatus
	 * @param SpeedStatus
	 *            Geschwindigkeit
	 * @param SpeedStatus16
	 *            Geschwindigkeit (nicht dokumentiert)
	 * @param ModeStatus
	 *            Mode-Status
	 * @return Fehlercode
	 */
	public native int jrRobMotors(int iHandle, int MotorStatus,
			int SpeedStatus, int SpeedStatus16, int ModeStatus);

	/**
	 * Abfragen des Counter an einem I-Eingang
	 * 
	 * @param iHandle
	 *            iHandle
	 * @param CounterNr
	 *            die Nummer des Counters
	 * @return Wert des Counters
	 */
	public native int jrGetCounter(int iHandle, int CounterNr);

	/**
	 * Setzen eines Counters auf 0
	 * 
	 * @param iHandle
	 *            iHandle
	 * @param CounterNr
	 *            die Nummer des Counters
	 * @param ICount
	 *            der Wert, der gesetzt werden soll
	 * @return Fehlercode
	 */
	public native int jrSetCounter(int iHandle, int CounterNr, int ICount);

	/**
	 * Lschen aller Counter
	 * 
	 * @param iHandle
	 *            iHandle
	 * @return Fehlercode
	 */
	public native int jrClearCounters(int iHandle);

	/**
	 * Auslesen des aktuellen Werte in cm des angegebenenUltraschallsensors,
	 * DistanceMode muss bei jrOpenInterface = UltraSonic sein
	 * 
	 * @param iHandle
	 *            iHandle
	 * @param SensorNr
	 *            die Nummer des Distanzsensor
	 * @return die Distanz am D-Eingang
	 */
	public native int jrGetDistanceValue(int iHandle, int SensorNr);

	/**
	 * Abfrage des akutellen Device-Typs
	 * 
	 * @param iHandle
	 *            iHandle
	 * @return den aktuellen DeviceTyp
	 */
	public native int jrGetActDeviceType(int iHandle);

	/**
	 * Abfrage der Seriennummer
	 * 
	 * @param iHandle
	 *            iHandle
	 * @return die Seriennummer
	 */
	public native int jrGetActDeviceSerialNr(int iHandle);

	/**
	 * Abfrage der Firmwareversion
	 * 
	 * @param iHandle
	 *            iHandle
	 * @return die Firmwareverion (unformatiert)
	 */
	public native int jrGetActDeviceFirmwareNr(int iHandle);

	/**
	 * allgemeiner Fehlercode,
	 */
	public static final int jrError = 0xE0000001;

	/**
	 * Prfen ob Escape-Taste gedrckt ist
	 * 
	 * @return 1 wenn Taste gedrckt, sonst 0
	 */
	public static native int escape();

	/**
	 * Systemfunktion Timer-Ticks
	 * 
	 * @return Timer-Ticks
	 */
	public static native int getTickCount();

	/**
	 * Anhalten des aktuellen Threads fr eine bestimmte Zeitspanne
	 * 
	 * @param MilliSec
	 *            Zeit in Millisekunden
	 */
	public static native void sleep(int MilliSec);

	static {
		try {
			System.loadLibrary("javaFish40");
		} catch (UnsatisfiedLinkError ex) {
			System.err.println("javaFish40.DLL konnte nicht geladen werden");
		}
	}
}